@@ -26,6 +26,9 @@
 
 #include <gio/gio.h>
 
+#define XDG_PORTAL_APPLICATIONS_DIR "xdg-desktop-portal" G_DIR_SEPARATOR_S "applications"
+#define XDG_PORTAL_ICONS_DIR "xdg-desktop-portal" G_DIR_SEPARATOR_S "icons"
+
 GDBusInterfaceSkeleton * dynamic_launcher_create (GDBusConnection *connection,
                                                   const char      *dbus_name);
 
