@@ -53,7 +53,7 @@ guint g_string_replace (GString     *string,
 #endif
 
 #if !GLIB_CHECK_VERSION (2, 68, 0)
-static void
+static inline void
 g_log_writer_default_set_use_stderr (gboolean use_stderr)
 {
   /* Does nothing because outside of the tests we don't really care that it
