@@ -33,26 +33,28 @@ typedef struct _NetworkMonitorClass NetworkMonitorClass;
 
 struct _NetworkMonitor
 {
-  XdpNetworkMonitorSkeleton parent_instance;
+  XdpDbusNetworkMonitorSkeleton parent_instance;
 
   GNetworkMonitor *monitor;
 };
 
 struct _NetworkMonitorClass
 {
-  XdpNetworkMonitorSkeletonClass parent_class;
+  XdpDbusNetworkMonitorSkeletonClass parent_class;
 };
 
 static NetworkMonitor *network_monitor;
 
 GType network_monitor_get_type (void) G_GNUC_CONST;
-static void network_monitor_iface_init (XdpNetworkMonitorIface *iface);
+static void network_monitor_iface_init (XdpDbusNetworkMonitorIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (NetworkMonitor, network_monitor, XDP_TYPE_NETWORK_MONITOR_SKELETON,
-                         G_IMPLEMENT_INTERFACE (XDP_TYPE_NETWORK_MONITOR, network_monitor_iface_init));
+G_DEFINE_TYPE_WITH_CODE (NetworkMonitor, network_monitor,
+                         XDP_DBUS_TYPE_NETWORK_MONITOR_SKELETON,
+                         G_IMPLEMENT_INTERFACE (XDP_DBUS_TYPE_NETWORK_MONITOR,
+                                                network_monitor_iface_init));
 
 static gboolean
-handle_get_available (XdpNetworkMonitor     *object,
+handle_get_available (XdpDbusNetworkMonitor *object,
                       GDBusMethodInvocation *invocation)
 {
   Request *request = request_from_invocation (invocation);
@@ -76,7 +78,7 @@ handle_get_available (XdpNetworkMonitor     *object,
 }
 
 static gboolean
-handle_get_metered (XdpNetworkMonitor     *object,
+handle_get_metered (XdpDbusNetworkMonitor *object,
                     GDBusMethodInvocation *invocation)
 {
   Request *request = request_from_invocation (invocation);
@@ -100,7 +102,7 @@ handle_get_metered (XdpNetworkMonitor     *object,
 }
 
 static gboolean
-handle_get_connectivity (XdpNetworkMonitor     *object,
+handle_get_connectivity (XdpDbusNetworkMonitor *object,
                          GDBusMethodInvocation *invocation)
 {
   Request *request = request_from_invocation (invocation);
@@ -124,7 +126,7 @@ handle_get_connectivity (XdpNetworkMonitor     *object,
 }
 
 static gboolean
-handle_get_status (XdpNetworkMonitor     *object,
+handle_get_status (XdpDbusNetworkMonitor *object,
                    GDBusMethodInvocation *invocation)
 {
   Request *request = request_from_invocation (invocation);
@@ -174,7 +176,7 @@ can_reach_done (GObject      *source,
 }
 
 static gboolean
-handle_can_reach (XdpNetworkMonitor     *object,
+handle_can_reach (XdpDbusNetworkMonitor *object,
                   GDBusMethodInvocation *invocation,
                   const char            *hostname,
                   guint                  port)
@@ -201,7 +203,7 @@ handle_can_reach (XdpNetworkMonitor     *object,
 }
 
 static void
-network_monitor_iface_init (XdpNetworkMonitorIface *iface)
+network_monitor_iface_init (XdpDbusNetworkMonitorIface *iface)
 {
   iface->handle_get_available = handle_get_available;
   iface->handle_get_metered = handle_get_metered;
@@ -215,7 +217,7 @@ network_changed (GObject *object,
                  gboolean network_available,
                  NetworkMonitor *nm)
 {
-  xdp_network_monitor_emit_changed (XDP_NETWORK_MONITOR (nm));
+  xdp_dbus_network_monitor_emit_changed (XDP_DBUS_NETWORK_MONITOR (nm));
 }
 
 static void
@@ -225,7 +227,7 @@ network_monitor_init (NetworkMonitor *nm)
 
   g_signal_connect (nm->monitor, "network-changed", G_CALLBACK (network_changed), nm);
 
-  xdp_network_monitor_set_version (XDP_NETWORK_MONITOR (nm), 3);
+  xdp_dbus_network_monitor_set_version (XDP_DBUS_NETWORK_MONITOR (nm), 3);
 }
 
 static void
