@@ -59,12 +59,12 @@ typedef struct _OpenURIClass OpenURIClass;
 
 struct _OpenURI
 {
-  XdpOpenURISkeleton parent_instance;
+  XdpDbusOpenURISkeleton parent_instance;
 };
 
 struct _OpenURIClass
 {
-  XdpOpenURISkeletonClass parent_class;
+  XdpDbusOpenURISkeletonClass parent_class;
 };
 
 enum {
@@ -74,16 +74,17 @@ enum {
   LAST_PERM
 };
 
-static XdpImplAppChooser *impl;
+static XdpDbusImplAppChooser *impl;
 static OpenURI *open_uri;
 static GAppInfoMonitor *monitor;
-static XdpImplLockdown *lockdown;
+static XdpDbusImplLockdown *lockdown;
 
 GType open_uri_get_type (void) G_GNUC_CONST;
-static void open_uri_iface_init (XdpOpenURIIface *iface);
+static void open_uri_iface_init (XdpDbusOpenURIIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (OpenURI, open_uri, XDP_TYPE_OPEN_URI_SKELETON,
-                         G_IMPLEMENT_INTERFACE (XDP_TYPE_OPEN_URI, open_uri_iface_init));
+G_DEFINE_TYPE_WITH_CODE (OpenURI, open_uri, XDP_DBUS_TYPE_OPEN_URI_SKELETON,
+                         G_IMPLEMENT_INTERFACE (XDP_DBUS_TYPE_OPEN_URI,
+                                                open_uri_iface_init));
 
 static void
 parse_permissions (const char **permissions,
@@ -130,13 +131,13 @@ get_latest_choice_info (const char *app_id,
   g_autoptr(GVariant) out_perms = NULL;
   g_autoptr(GVariant) out_data = NULL;
 
-  if (!xdp_impl_permission_store_call_lookup_sync (get_permission_store (),
-                                                   PERMISSION_TABLE,
-                                                   content_type,
-                                                   &out_perms,
-                                                   &out_data,
-                                                   NULL,
-                                                   &error))
+  if (!xdp_dbus_impl_permission_store_call_lookup_sync (get_permission_store (),
+                                                        PERMISSION_TABLE,
+                                                        content_type,
+                                                        &out_perms,
+                                                        &out_data,
+                                                        NULL,
+                                                        &error))
     {
       g_dbus_error_strip_remote_error (error);
       /* Not finding an entry for the content type in the permission store is perfectly ok */
@@ -240,6 +241,7 @@ launch_application_with_uri (const char *choice_id,
   g_autoptr(GDesktopAppInfo) info = g_desktop_app_info_new (desktop_id);
   g_autoptr(GAppLaunchContext) context = g_app_launch_context_new ();
   g_autofree char *ruri = NULL;
+  DocumentFlags flags = DOCUMENT_FLAG_NONE;
   GList uris;
 
   if (info == NULL)
@@ -256,8 +258,10 @@ launch_application_with_uri (const char *choice_id,
       g_autoptr(GError) local_error = NULL;
 
       g_debug ("Registering %s for %s", uri, choice_id);
+      if (writable)
+        flags |= DOCUMENT_FLAG_WRITABLE;
 
-      ruri = register_document (uri, choice_id, FALSE, writable, FALSE, &local_error);
+      ruri = register_document (uri, choice_id, flags, &local_error);
       if (ruri == NULL)
         {
           g_warning ("Error registering %s for %s: %s", uri, choice_id, local_error->message);
@@ -322,14 +326,14 @@ update_permissions_store (const char *app_id,
            in_permissions[PERM_APP_THRESHOLD]);
 
 
-  if (!xdp_impl_permission_store_call_set_permission_sync (get_permission_store (),
-                                                           PERMISSION_TABLE,
-                                                           TRUE,
-                                                           content_type,
-                                                           app_id,
-                                                           (const char * const*) in_permissions,
-                                                           NULL,
-                                                           &error))
+  if (!xdp_dbus_impl_permission_store_call_set_permission_sync (get_permission_store (),
+                                                                PERMISSION_TABLE,
+                                                                TRUE,
+                                                                content_type,
+                                                                app_id,
+                                                                (const char * const*) in_permissions,
+                                                                NULL,
+                                                                &error))
     {
       g_dbus_error_strip_remote_error (error);
       g_warning ("Error updating permission store: %s", error->message);
@@ -383,7 +387,9 @@ send_response_in_thread_func (GTask *task,
 out:
   if (request->exported)
     {
-      xdp_request_emit_response (XDP_REQUEST (request), response, g_variant_builder_end (&opt_builder));
+      xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                      response,
+                                      g_variant_builder_end (&opt_builder));
       request_unexport (request);
     }
 }
@@ -399,11 +405,11 @@ app_chooser_done (GObject *source,
   g_autoptr(GError) error = NULL;
   g_autoptr(GTask) task = NULL;
 
-  if (!xdp_impl_app_chooser_call_choose_application_finish (XDP_IMPL_APP_CHOOSER (source),
-                                                            &response,
-                                                            &options,
-                                                            result,
-                                                            &error))
+  if (!xdp_dbus_impl_app_chooser_call_choose_application_finish (XDP_DBUS_IMPL_APP_CHOOSER (source),
+                                                                 &response,
+                                                                 &options,
+                                                                 result,
+                                                                 &error))
     {
       g_dbus_error_strip_remote_error (error);
       g_warning ("Backend call failed: %s", error->message);
@@ -556,12 +562,12 @@ app_info_changed (GAppInfoMonitor *monitor,
   content_type = (const char *)g_object_get_data (G_OBJECT (request), "content-type");
   find_recommended_choices (scheme, content_type, &default_app, &choices, &n_choices);
 
-  xdp_impl_app_chooser_call_update_choices (impl,
-                                            request->id,
-                                            (const char * const *)choices,
-                                            NULL,
-                                            NULL,
-                                            NULL);
+  xdp_dbus_impl_app_chooser_call_update_choices (impl,
+                                                 request->id,
+                                                 (const char * const *)choices,
+                                                 NULL,
+                                                 NULL,
+                                                 NULL);
 }
 
 static gboolean
@@ -588,7 +594,7 @@ handle_open_in_thread_func (GTask *task,
   const char *app_id = xdp_app_info_get_id (request->app_info);
   const char *activation_token;
   g_autofree char *uri = NULL;
-  g_autoptr(XdpImplRequest) impl_request = NULL;
+  g_autoptr(XdpDbusImplRequest) impl_request = NULL;
   g_autofree char *default_app = NULL;
   g_auto(GStrv) choices = NULL;
   guint n_choices;
@@ -625,9 +631,9 @@ handle_open_in_thread_func (GTask *task,
       if (request->exported)
         {
           g_variant_builder_init (&opts_builder, G_VARIANT_TYPE_VARDICT);
-          xdp_request_emit_response (XDP_REQUEST (request),
-                                     XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
-                                     g_variant_builder_end (&opts_builder));
+          xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                          XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
+                                          g_variant_builder_end (&opts_builder));
           request_unexport (request);
         }
       return;
@@ -643,9 +649,9 @@ handle_open_in_thread_func (GTask *task,
             {
               g_debug ("Rejecting open request as content-type couldn't be fetched for '%s'", uri);
               g_variant_builder_init (&opts_builder, G_VARIANT_TYPE_VARDICT);
-              xdp_request_emit_response (XDP_REQUEST (request),
-                                         XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
-                                         g_variant_builder_end (&opts_builder));
+              xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                              XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
+                                              g_variant_builder_end (&opts_builder));
               request_unexport (request);
             }
           return;
@@ -676,9 +682,9 @@ handle_open_in_thread_func (GTask *task,
           if (request->exported)
             {
               g_variant_builder_init (&opts_builder, G_VARIANT_TYPE_VARDICT);
-              xdp_request_emit_response (XDP_REQUEST (request),
-                                         XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
-                                         g_variant_builder_end (&opts_builder));
+              xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                              XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
+                                              g_variant_builder_end (&opts_builder));
               request_unexport (request);
             }
           return;
@@ -727,9 +733,9 @@ handle_open_in_thread_func (GTask *task,
           else
             {
               g_variant_builder_init (&opts_builder, G_VARIANT_TYPE_VARDICT);
-              xdp_request_emit_response (XDP_REQUEST (request),
-                                         XDG_DESKTOP_PORTAL_RESPONSE_SUCCESS,
-                                         g_variant_builder_end (&opts_builder));
+              xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                              XDG_DESKTOP_PORTAL_RESPONSE_SUCCESS,
+                                              g_variant_builder_end (&opts_builder));
               request_unexport (request);
               return;
             }
@@ -834,9 +840,9 @@ handle_open_in_thread_func (GTask *task,
               if (!result)
                 g_debug ("Open request for '%s' failed: %s", uri, error->message);
               g_variant_builder_init (&opts_builder, G_VARIANT_TYPE_VARDICT);
-              xdp_request_emit_response (XDP_REQUEST (request),
-                                         result ? XDG_DESKTOP_PORTAL_RESPONSE_SUCCESS : XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
-                                         g_variant_builder_end (&opts_builder));
+              xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                              result ? XDG_DESKTOP_PORTAL_RESPONSE_SUCCESS : XDG_DESKTOP_PORTAL_RESPONSE_OTHER,
+                                              g_variant_builder_end (&opts_builder));
               request_unexport (request);
             }
 
@@ -861,11 +867,12 @@ handle_open_in_thread_func (GTask *task,
   if (activation_token)
     g_variant_builder_add (&opts_builder, "{sv}", "activation_token", g_variant_new_string (uri));
 
-  impl_request = xdp_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                                  G_DBUS_PROXY_FLAGS_NONE,
-                                                  g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
-                                                  request->id,
-                                                  NULL, NULL);
+  impl_request =
+    xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
+                                          G_DBUS_PROXY_FLAGS_NONE,
+                                          g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
+                                          request->id,
+                                          NULL, NULL);
 
   request_set_impl_request (request, impl_request);
 
@@ -873,19 +880,19 @@ handle_open_in_thread_func (GTask *task,
 
   g_debug ("Opening app chooser");
 
-  xdp_impl_app_chooser_call_choose_application (impl,
-                                                request->id,
-                                                app_id,
-                                                parent_window,
-                                                (const char * const *)choices,
-                                                g_variant_builder_end (&opts_builder),
-                                                NULL,
-                                                app_chooser_done,
-                                                g_object_ref (request));
+  xdp_dbus_impl_app_chooser_call_choose_application (impl,
+                                                     request->id,
+                                                     app_id,
+                                                     parent_window,
+                                                     (const char * const *)choices,
+                                                     g_variant_builder_end (&opts_builder),
+                                                     NULL,
+                                                     app_chooser_done,
+                                                     g_object_ref (request));
 }
 
 static gboolean
-handle_open_uri (XdpOpenURI *object,
+handle_open_uri (XdpDbusOpenURI *object,
                  GDBusMethodInvocation *invocation,
                  const gchar *arg_parent_window,
                  const gchar *arg_uri,
@@ -897,7 +904,7 @@ handle_open_uri (XdpOpenURI *object,
   gboolean ask;
   const char *activation_token = NULL;
 
-  if (xdp_impl_lockdown_get_disable_application_handlers (lockdown))
+  if (xdp_dbus_impl_lockdown_get_disable_application_handlers (lockdown))
     {
       g_debug ("Application handlers disabled");
       g_dbus_method_invocation_return_error (invocation,
@@ -925,7 +932,7 @@ handle_open_uri (XdpOpenURI *object,
     g_object_set_data_full (G_OBJECT (request), "activation-token", g_strdup (activation_token), g_free);
 
   request_export (request, g_dbus_method_invocation_get_connection (invocation));
-  xdp_open_uri_complete_open_uri (object, invocation, request->id);
+  xdp_dbus_open_uri_complete_open_uri (object, invocation, request->id);
 
   task = g_task_new (object, NULL, NULL, NULL);
   g_task_set_task_data (task, g_object_ref (request), g_object_unref);
@@ -935,7 +942,7 @@ handle_open_uri (XdpOpenURI *object,
 }
 
 static gboolean
-handle_open_file (XdpOpenURI *object,
+handle_open_file (XdpDbusOpenURI *object,
                  GDBusMethodInvocation *invocation,
                  GUnixFDList *fd_list,
                  const gchar *arg_parent_window,
@@ -950,7 +957,7 @@ handle_open_file (XdpOpenURI *object,
   const char *activation_token = NULL;
   g_autoptr(GError) error = NULL;
 
-  if (xdp_impl_lockdown_get_disable_application_handlers (lockdown))
+  if (xdp_dbus_impl_lockdown_get_disable_application_handlers (lockdown))
     {
       g_debug ("Application handlers disabled");
       g_dbus_method_invocation_return_error (invocation,
@@ -985,7 +992,7 @@ handle_open_file (XdpOpenURI *object,
     g_object_set_data_full (G_OBJECT (request), "activation-token", g_strdup (activation_token), g_free);
 
   request_export (request, g_dbus_method_invocation_get_connection (invocation));
-  xdp_open_uri_complete_open_file (object, invocation, NULL, request->id);
+  xdp_dbus_open_uri_complete_open_file (object, invocation, NULL, request->id);
 
   task = g_task_new (object, NULL, NULL, NULL);
   g_task_set_task_data (task, g_object_ref (request), g_object_unref);
@@ -995,7 +1002,7 @@ handle_open_file (XdpOpenURI *object,
 }
 
 static gboolean
-handle_open_directory (XdpOpenURI *object,
+handle_open_directory (XdpDbusOpenURI *object,
                        GDBusMethodInvocation *invocation,
                        GUnixFDList *fd_list,
                        const gchar *arg_parent_window,
@@ -1008,7 +1015,7 @@ handle_open_directory (XdpOpenURI *object,
   const char *activation_token = NULL;
   g_autoptr(GError) error = NULL;
 
-  if (xdp_impl_lockdown_get_disable_application_handlers (lockdown))
+  if (xdp_dbus_impl_lockdown_get_disable_application_handlers (lockdown))
     {
       g_debug ("Application handlers disabled");
       g_dbus_method_invocation_return_error (invocation,
@@ -1038,7 +1045,7 @@ handle_open_directory (XdpOpenURI *object,
     g_object_set_data_full (G_OBJECT (request), "activation-token", g_strdup (activation_token), g_free);
 
   request_export (request, g_dbus_method_invocation_get_connection (invocation));
-  xdp_open_uri_complete_open_file (object, invocation, NULL, request->id);
+  xdp_dbus_open_uri_complete_open_file (object, invocation, NULL, request->id);
 
   task = g_task_new (object, NULL, NULL, NULL);
   g_task_set_task_data (task, g_object_ref (request), g_object_unref);
@@ -1048,7 +1055,7 @@ handle_open_directory (XdpOpenURI *object,
 }
 
 static void
-open_uri_iface_init (XdpOpenURIIface *iface)
+open_uri_iface_init (XdpDbusOpenURIIface *iface)
 {
   iface->handle_open_uri = handle_open_uri;
   iface->handle_open_file = handle_open_file;
@@ -1058,7 +1065,7 @@ open_uri_iface_init (XdpOpenURIIface *iface)
 static void
 open_uri_init (OpenURI *openuri)
 {
-  xdp_open_uri_set_version (XDP_OPEN_URI (openuri), 3);
+  xdp_dbus_open_uri_set_version (XDP_DBUS_OPEN_URI (openuri), 3);
 }
 
 static void
@@ -1075,11 +1082,11 @@ open_uri_create (GDBusConnection *connection,
 
   lockdown = lockdown_proxy;
 
-  impl = xdp_impl_app_chooser_proxy_new_sync (connection,
-                                              G_DBUS_PROXY_FLAGS_NONE,
-                                              dbus_name,
-                                              DESKTOP_PORTAL_OBJECT_PATH,
-                                              NULL, &error);
+  impl = xdp_dbus_impl_app_chooser_proxy_new_sync (connection,
+                                                   G_DBUS_PROXY_FLAGS_NONE,
+                                                   dbus_name,
+                                                   DESKTOP_PORTAL_OBJECT_PATH,
+                                                   NULL, &error);
   if (impl == NULL)
     {
       g_warning ("Failed to create app chooser proxy: %s", error->message);
