@@ -43,23 +43,24 @@ typedef struct _PrintClass PrintClass;
 
 struct _Print
 {
-  XdpPrintSkeleton parent_instance;
+  XdpDbusPrintSkeleton parent_instance;
 };
 
 struct _PrintClass
 {
-  XdpPrintSkeletonClass parent_class;
+  XdpDbusPrintSkeletonClass parent_class;
 };
 
-static XdpImplPrint *impl;
+static XdpDbusImplPrint *impl;
 static Print *print;
-static XdpImplLockdown *lockdown;
+static XdpDbusImplLockdown *lockdown;
 
 GType print_get_type (void) G_GNUC_CONST;
-static void print_iface_init (XdpPrintIface *iface);
+static void print_iface_init (XdpDbusPrintIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (Print, print, XDP_TYPE_PRINT_SKELETON,
-                         G_IMPLEMENT_INTERFACE (XDP_TYPE_PRINT, print_iface_init));
+G_DEFINE_TYPE_WITH_CODE (Print, print, XDP_DBUS_TYPE_PRINT_SKELETON,
+                         G_IMPLEMENT_INTERFACE (XDP_DBUS_TYPE_PRINT,
+                                                print_iface_init));
 
 static void
 print_done (GObject *source,
@@ -73,12 +74,12 @@ print_done (GObject *source,
 
   REQUEST_AUTOLOCK (request);
 
-  if (!xdp_impl_print_call_print_finish (XDP_IMPL_PRINT (source),
-                                         &response,
-                                         &options,
-                                         NULL,
-                                         result,
-                                         &error))
+  if (!xdp_dbus_impl_print_call_print_finish (XDP_DBUS_IMPL_PRINT (source),
+                                              &response,
+                                              &options,
+                                              NULL,
+                                              result,
+                                              &error))
     {
       g_dbus_error_strip_remote_error (error);
       g_warning ("Backend call failed: %s", error->message);
@@ -90,9 +91,9 @@ print_done (GObject *source,
 
       g_variant_builder_init (&opt_builder, G_VARIANT_TYPE_VARDICT);
 
-      xdp_request_emit_response (XDP_REQUEST (request),
-                                 response,
-                                 g_variant_builder_end (&opt_builder));
+      xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                      response,
+                                      g_variant_builder_end (&opt_builder));
       request_unexport (request);
     }
 }
@@ -103,7 +104,7 @@ static XdpOptionKey print_options[] = {
 };
 
 static gboolean
-handle_print (XdpPrint *object,
+handle_print (XdpDbusPrint *object,
               GDBusMethodInvocation *invocation,
               GUnixFDList *fd_list,
               const gchar *arg_parent_window,
@@ -114,10 +115,10 @@ handle_print (XdpPrint *object,
   Request *request = request_from_invocation (invocation);
   const char *app_id = xdp_app_info_get_id (request->app_info);
   g_autoptr(GError) error = NULL;
-  g_autoptr(XdpImplRequest) impl_request = NULL;
+  g_autoptr(XdpDbusImplRequest) impl_request = NULL;
   GVariantBuilder opt_builder;
 
-  if (xdp_impl_lockdown_get_disable_printing (lockdown))
+  if (xdp_dbus_impl_lockdown_get_disable_printing (lockdown))
     {
       g_debug ("Printing disabled");
       g_dbus_method_invocation_return_error (invocation,
@@ -130,11 +131,11 @@ handle_print (XdpPrint *object,
 
   REQUEST_AUTOLOCK (request);
 
-  impl_request = xdp_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                                  G_DBUS_PROXY_FLAGS_NONE,
-                                                  g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
-                                                  request->id,
-                                                  NULL, &error);
+  impl_request = xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
+                                                       G_DBUS_PROXY_FLAGS_NONE,
+                                                       g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
+                                                       request->id,
+                                                       NULL, &error);
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
@@ -147,19 +148,19 @@ handle_print (XdpPrint *object,
   g_variant_builder_init (&opt_builder, G_VARIANT_TYPE_VARDICT);
   xdp_filter_options (arg_options, &opt_builder,
                       print_options, G_N_ELEMENTS (print_options), NULL);
-  xdp_impl_print_call_print(impl,
-                            request->id,
-                            app_id,
-                            arg_parent_window,
-                            arg_title,
-                            arg_fd,
-                            g_variant_builder_end (&opt_builder),
-                            fd_list,
-                            NULL,
-                            print_done,
-                            g_object_ref (request));
+  xdp_dbus_impl_print_call_print(impl,
+                                 request->id,
+                                 app_id,
+                                 arg_parent_window,
+                                 arg_title,
+                                 arg_fd,
+                                 g_variant_builder_end (&opt_builder),
+                                 fd_list,
+                                 NULL,
+                                 print_done,
+                                 g_object_ref (request));
 
-  xdp_print_complete_print (object, invocation, NULL, request->id);
+  xdp_dbus_print_complete_print (object, invocation, NULL, request->id);
 
   return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
@@ -182,11 +183,11 @@ prepare_print_done (GObject *source,
 
   REQUEST_AUTOLOCK (request);
 
-  if (!xdp_impl_print_call_prepare_print_finish (XDP_IMPL_PRINT (source),
-                                                 &response,
-                                                 &options,
-                                                 result,
-                                                 &error))
+  if (!xdp_dbus_impl_print_call_prepare_print_finish (XDP_DBUS_IMPL_PRINT (source),
+                                                      &response,
+                                                      &options,
+                                                      result,
+                                                      &error))
     {
       g_dbus_error_strip_remote_error (error);
       g_warning ("Backend call failed: %s", error->message);
@@ -203,9 +204,9 @@ prepare_print_done (GObject *source,
                             response_options, G_N_ELEMENTS (response_options),
                             NULL);
 
-      xdp_request_emit_response (XDP_REQUEST (request),
-                                 response,
-                                 g_variant_builder_end (&opt_builder));
+      xdp_dbus_request_emit_response (XDP_DBUS_REQUEST (request),
+                                      response,
+                                      g_variant_builder_end (&opt_builder));
 
       request_unexport (request);
     }
@@ -216,7 +217,7 @@ static XdpOptionKey prepare_print_options[] = {
 };
 
 static gboolean
-handle_prepare_print (XdpPrint *object,
+handle_prepare_print (XdpDbusPrint *object,
                       GDBusMethodInvocation *invocation,
                       const gchar *arg_parent_window,
                       const gchar *arg_title,
@@ -227,10 +228,10 @@ handle_prepare_print (XdpPrint *object,
   Request *request = request_from_invocation (invocation);
   const char *app_id = xdp_app_info_get_id (request->app_info);
   g_autoptr(GError) error = NULL;
-  g_autoptr(XdpImplRequest) impl_request = NULL;
+  g_autoptr(XdpDbusImplRequest) impl_request = NULL;
   GVariantBuilder opt_builder;
 
-  if (xdp_impl_lockdown_get_disable_printing (lockdown))
+  if (xdp_dbus_impl_lockdown_get_disable_printing (lockdown))
     {
       g_debug ("Printing disabled");
       g_dbus_method_invocation_return_error (invocation,
@@ -242,11 +243,11 @@ handle_prepare_print (XdpPrint *object,
 
   REQUEST_AUTOLOCK (request);
 
-  impl_request = xdp_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
-                                                  G_DBUS_PROXY_FLAGS_NONE,
-                                                  g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
-                                                  request->id,
-                                                  NULL, &error);
+  impl_request = xdp_dbus_impl_request_proxy_new_sync (g_dbus_proxy_get_connection (G_DBUS_PROXY (impl)),
+                                                       G_DBUS_PROXY_FLAGS_NONE,
+                                                       g_dbus_proxy_get_name (G_DBUS_PROXY (impl)),
+                                                       request->id,
+                                                       NULL, &error);
   if (!impl_request)
     {
       g_dbus_method_invocation_return_gerror (invocation, error);
@@ -259,25 +260,25 @@ handle_prepare_print (XdpPrint *object,
   g_variant_builder_init (&opt_builder, G_VARIANT_TYPE_VARDICT);
   xdp_filter_options (arg_options, &opt_builder,
                       prepare_print_options, G_N_ELEMENTS (prepare_print_options), NULL);
-  xdp_impl_print_call_prepare_print (impl,
-                                     request->id,
-                                     app_id,
-                                     arg_parent_window,
-                                     arg_title,
-                                     arg_settings,
-                                     arg_page_setup,
-                                     g_variant_builder_end (&opt_builder),
-                                     NULL,
-                                     prepare_print_done,
-                                     g_object_ref (request));
+  xdp_dbus_impl_print_call_prepare_print (impl,
+                                          request->id,
+                                          app_id,
+                                          arg_parent_window,
+                                          arg_title,
+                                          arg_settings,
+                                          arg_page_setup,
+                                          g_variant_builder_end (&opt_builder),
+                                          NULL,
+                                          prepare_print_done,
+                                          g_object_ref (request));
 
-  xdp_print_complete_prepare_print (object, invocation, request->id);
+  xdp_dbus_print_complete_prepare_print (object, invocation, request->id);
 
   return G_DBUS_METHOD_INVOCATION_HANDLED;
 }
 
 static void
-print_iface_init (XdpPrintIface *iface)
+print_iface_init (XdpDbusPrintIface *iface)
 {
   iface->handle_print = handle_print;
   iface->handle_prepare_print = handle_prepare_print;
@@ -286,7 +287,7 @@ print_iface_init (XdpPrintIface *iface)
 static void
 print_init (Print *print)
 {
-  xdp_print_set_version (XDP_PRINT (print), 1);
+  xdp_dbus_print_set_version (XDP_DBUS_PRINT (print), 1);
 }
 
 static void
@@ -303,12 +304,12 @@ print_create (GDBusConnection *connection,
 
   lockdown = lockdown_proxy;
 
-  impl = xdp_impl_print_proxy_new_sync (connection,
-                                        G_DBUS_PROXY_FLAGS_NONE,
-                                        dbus_name,
-                                        DESKTOP_PORTAL_OBJECT_PATH,
-                                        NULL,
-                                        &error);
+  impl = xdp_dbus_impl_print_proxy_new_sync (connection,
+                                             G_DBUS_PROXY_FLAGS_NONE,
+                                             dbus_name,
+                                             DESKTOP_PORTAL_OBJECT_PATH,
+                                             NULL,
+                                             &error);
   if (impl == NULL)
     {
       g_warning ("Failed to create print proxy: %s", error->message);
