@@ -21,46 +21,52 @@
 
 #pragma once
 
+#include "xdp-utils.h"
 #include "xdp-dbus.h"
 #include "xdp-impl-dbus.h"
 
+typedef enum {
+  XDG_DESKTOP_PORTAL_RESPONSE_SUCCESS = 0,
+  XDG_DESKTOP_PORTAL_RESPONSE_CANCELLED,
+  XDG_DESKTOP_PORTAL_RESPONSE_OTHER
+} XdgDesktopPortalResponseEnum;
+
 typedef struct _Request Request;
 typedef struct _RequestClass RequestClass;
 
 struct _Request
 {
-  XdpRequestSkeleton parent_instance;
+  XdpDbusRequestSkeleton parent_instance;
 
   gboolean exported;
-  char *app_id;
   char *id;
   char *sender;
   GMutex mutex;
-  GKeyFile *app_info;
+  XdpAppInfo *app_info;
 
-  XdpImplRequest *impl_request;
+  XdpDbusImplRequest *impl_request;
 };
 
 struct _RequestClass
 {
-  XdpRequestSkeletonClass parent_class;
+  XdpDbusRequestSkeletonClass parent_class;
 };
 
 GType request_get_type (void) G_GNUC_CONST;
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (Request, g_object_unref)
 
-void request_init_invocation (GDBusMethodInvocation  *invocation, const char *app_id);
+void request_init_invocation (GDBusMethodInvocation  *invocation, XdpAppInfo *app_info);
 Request *request_from_invocation (GDBusMethodInvocation *invocation);
 void request_export (Request *request,
                      GDBusConnection *connection);
 void request_unexport (Request *request);
 void close_requests_for_sender (const char *sender);
 
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (XdpImplRequest, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (XdpDbusImplRequest, g_object_unref)
 
 void request_set_impl_request (Request *request,
-                               XdpImplRequest *impl_request);
+                               XdpDbusImplRequest *impl_request);
 
 static inline void
 auto_unlock_helper (GMutex **mutex)
