@@ -29,7 +29,12 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
+#ifdef HAVE_SYS_VFS_H
 #include <sys/vfs.h>
+#endif
+#ifdef HAVE_SYS_MOUNT_H
+#include <sys/mount.h>
+#endif
 
 #ifdef HAVE_LIBSYSTEMD
 #include <systemd/sd-login.h>
@@ -991,7 +996,7 @@ xdp_filter_options (GVariant *options,
 
           continue;
         }
-         
+
       if (supported_options[i].validate)
         {
           g_autoptr(GError) local_error = NULL;
